==> nautilus-gallery-uploader_1.1.tar.gz: nautilus-gallery-uploader_1.1/release.py <==
#! /usr/bin/python


import os, gtk, re, datetime, subprocess

version_re = re.compile('__version__ = ([0-9]*\.[0-9]*)')

DIR = os.path.dirname(os.path.realpath(__file__))

def current_version():
    f = open('Gallery Uploader.py')
    content = f.read()
    f.close()
    match = version_re.search(content)
    return float(match.groups()[0])

def get_informations():
    dialog = gtk.Dialog('New release informations', buttons=(gtk.STOCK_CANCEL,
                        gtk.RESPONSE_REJECT, gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
    hbox = gtk.HBox()
    hbox.pack_start(gtk.Label('Version number:'))
    number = gtk.Entry()
    hbox.pack_start(number)
    hbox.set_child_packing(number, False, False, 0, gtk.PACK_START)
    label = gtk.Label()
    scroll = gtk.ScrolledWindow()
    textview = gtk.TextView()
    scroll.add_with_viewport(textview)
    textbuf = gtk.TextBuffer()
    textbuf.set_text('  * \n  * ')
    textview.set_buffer(textbuf)
    current = current_version()
    number.set_text(str(current + 0.1))

    dialog.vbox.pack_start(hbox)
    dialog.vbox.pack_start(label)
    dialog.vbox.pack_start(scroll)
    label.show_all()
    hbox.show_all()
    scroll.show_all()
    
    def update_label(*args):
        label.set_text('gallery-uploader %s, %s' % (number.get_text(), str(datetime.date.today()) ) )
        
    number.connect('changed', update_label)
    
    update_label()

    resp = dialog.run()
    
    if resp == gtk.RESPONSE_ACCEPT:
        return number.get_text(), label.get_text() + '\n' + textbuf.get_text(textbuf.get_start_iter(), textbuf.get_end_iter()) + '\n\n'
    else:
        import sys
        sys.exit(0)

def replace(filename, version):
    f = open(filename)
    cont = f.read()
    f.close()
    m = version_re.search(cont)

    f = open(filename, 'w')
    f.write(cont[:m.start()] + '__version__ = %s' % str(version) + cont[m.end():])
    f.close()
        

def pack_new_release(version):
    subprocess.call(['git', 'add'] + ['Gallery Uploader.py', 'Upload to new Gallery profile.py'] + ['ChangeLog'])
    subprocess.call(['git', 'commit', '-m' 'Automatic release of version %s' % version])
    os.chdir('..')
    new_folder = 'nautilus-gallery-uploader_%s' % version
    subprocess.call(['git', 'clone', 'trunk', new_folder])
    subprocess.call(['tar', '-acf', new_folder+'.tar.gz', new_folder])
    subprocess.call(['rm', '-rf', new_folder])
    

def trace():
    import traceback
    def stringize(l):
        return [str(i) for i in l]
    return '\n'.join([' '.join(stringize(i)) for i in traceback.extract_stack()])

def main():
    

    version, changelog_adds = get_informations()

    f = open('ChangeLog')
    old_changes = f.read()
    f.close()

    new_changes = changelog_adds + old_changes

    f = open('ChangeLog', 'w')
    f.write(new_changes)
    f.close()

    for a_file in ['Gallery Uploader.py', 'Upload to new Gallery profile.py']:
        replace(a_file, version)
    
    pack_new_release(version)

if __name__ == '__main__':
    try:
        main()
    except Exception, msg:
        dialog = gtk.MessageDialog()
        dialog.set_title('Error')
        dialog.set_markup(str(msg))
        dialog.format_secondary_text(trace())
        resp = dialog.run()
        dialog.destroy()
        import sys
        sys.exit(1)

==> nautilus-gallery-uploader_1.3.tar.gz: nautilus-gallery-uploader_1.3/release.py <==
#! /usr/bin/python


import os, gtk, re, datetime, subprocess, shutil

version_re = re.compile('__version__ = ([0-9]*\.[0-9]*)')

DIR = os.path.dirname(os.path.realpath(__file__))

def current_version():
    f = open('Gallery Uploader.py')
    content = f.read()
    f.close()
    match = version_re.search(content)
    return float(match.groups()[0])

def get_informations():
    dialog = gtk.Dialog('New release informations', buttons=(gtk.STOCK_CANCEL,
                        gtk.RESPONSE_REJECT, gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
    hbox = gtk.HBox()
    hbox.pack_start(gtk.Label('Version number:'))
    number = gtk.Entry()
    hbox.pack_start(number)
    hbox.set_child_packing(number, False, False, 0, gtk.PACK_START)
    label = gtk.Label()
    scroll = gtk.ScrolledWindow()
    textview = gtk.TextView()
    scroll.add_with_viewport(textview)
    textbuf = gtk.TextBuffer()
    textbuf.set_text('  * \n  * ')
    textview.set_buffer(textbuf)
    current = current_version()
    number.set_text(str(current + 0.1))

    dialog.vbox.pack_start(hbox)
    dialog.vbox.pack_start(label)
    dialog.vbox.pack_start(scroll)
    label.show_all()
    hbox.show_all()
    scroll.show_all()
    
    def update_label(*args):
        label.set_text('gallery-uploader %s, %s' % (number.get_text(), str(datetime.date.today()) ) )
        
    number.connect('changed', update_label)
    
    update_label()

    resp = dialog.run()
    
    if resp == gtk.RESPONSE_ACCEPT:
        return number.get_text(), label.get_text() + '\n' + textbuf.get_text(textbuf.get_start_iter(), textbuf.get_end_iter()) + '\n\n'
    else:
        import sys
        sys.exit(0)

def replace(filename, version):
    f = open(filename)
    cont = f.read()
    f.close()
    m = version_re.search(cont)

    f = open(filename, 'w')
    f.write(cont[:m.start()] + '__version__ = %s' % str(version) + cont[m.end():])
    f.close()
        

def pack_new_release(version):
    subprocess.call(['git', 'add'] + ['Gallery Uploader.py', 'Upload to new Gallery profile.py'] + ['ChangeLog'])
    subprocess.call(['git', 'commit', '-m' 'Automatic release of version %s' % version])
    os.chdir('..')
    new_folder = 'nautilus-gallery-uploader_%s' % version
    subprocess.call(['git', 'clone', 'trunk', new_folder])
    shutil.rmtree(new_folder+'/.git')
    archive_name = new_folder+'.tar.gz'
    subprocess.call(['tar', '-acf', archive_name, new_folder])
    subprocess.call(['rm', '-rf', new_folder])
    return archive_name

def trace():
    import traceback
    def stringize(l):
        return [str(i) for i in l]
    return '\n'.join([' '.join(stringize(i)) for i in traceback.extract_stack()])

def main():
    

    version, changelog_adds = get_informations()

    f = open('ChangeLog')
    old_changes = f.read()
    f.close()

    new_changes = changelog_adds + old_changes

    f = open('ChangeLog', 'w')
    f.write(new_changes)
    f.close()

    for a_file in ['Gallery Uploader.py', 'Upload to new Gallery profile.py']:
        replace(a_file, version)
    
    archive_name = pack_new_release(version)
    
    OK = gtk.MessageDialog(buttons=gtk.BUTTONS_OK, message_format='Archive created as %s' % archive_name)
    OK.set_title('Done')
    OK.run()
    OK.destroy()

if __name__ == '__main__':
    try:
        main()
    except Exception, msg:
        dialog = gtk.MessageDialog()
        dialog.set_title('Error')
        dialog.set_markup(str(msg))
        dialog.format_secondary_text(trace())
        resp = dialog.run()
        dialog.destroy()
        import sys
        sys.exit(1)
